@@ -2,11 +2,11 @@
 
 """Release information about the Turbo-Mail mail queue."""
 
-version = "1.1.2"
+version = "2.0"
 description = "Multi-threaded mail queue manager for TurboGears applications."
 author = "Top Floor Computer Systems Ltd."
 email = "webmaster@topfloor.ca"
 url = "http://www.topfloor.ca/turbomail/"
-download_url = "http://www.topfloor.ca/turbomail/"
+download_url = "http://cheeseshop.python.org/pypi/TurboMail/"
 copyright = "© 2006 Top Floor Computer Systems Ltd."
 license="MIT"
